@@ -111,10 +111,10 @@ class ClassificationApp:
 
         # Scatter kdims and vdims
         is_cols = df_is.columns.to_list()
-        self.is_kdims = is_cols[0]
-        self.is_vdims = [is_cols[1], self.class_label] + self.meta_dims
-        self.data_kdims = self.data_dims[0]
-        self.data_vdims = [self.data_dims[1], self.class_label] + self.meta_dims
+        self.is_kdims = [is_cols[0], is_cols[1]]
+        self.is_vdims = [self.class_label] + self.meta_dims
+        self.data_kdims = [self.data_dims[0], self.data_dims[1]]
+        self.data_vdims = [self.class_label] + self.meta_dims
 
         # Markers
         markers = ['circle', 'triangle', 'square', 'diamond', 'asterisk', 'hex', '+', 'x']
@@ -296,7 +296,7 @@ class ClassificationApp:
         hover_list = list(dict.fromkeys(hover_list))
         tooltips = [(s[0], '@' + s[1]) for s in hover_list]  # [("Instance", "$index")] +
         hover = HoverTool(tooltips=tooltips)
-        scatter_pca = hv.Scatter(
+        scatter_pca = hv.Points(
             self.data,
             kdims=self.data_kdims,
             vdims=self.data_vdims
@@ -343,7 +343,7 @@ class ClassificationApp:
         hover_list = list(dict.fromkeys(hover_list))
         tooltips = [(s[0], '@' + s[1]) for s in hover_list]  # [("Instance", "$index")] +
         hover = HoverTool(tooltips=tooltips)
-        scatter_is = hv.Scatter(
+        scatter_is = hv.Points(
             self.data,
             kdims=self.is_kdims,
             vdims=self.is_vdims
@@ -397,15 +397,16 @@ class ClassificationApp:
         def update_isa_plot(color, lim, autorange_on):
             return self.instance_space(color, lim, autorange_on)
 
-        def selection_callback_pca(bbox, region_element, selection_expr, resetting):
-            if resetting:
-                bbox = None
-
+        def selection_callback_pca(bbox, region_element, selection_expr):
             if self.bbox is not bbox:
                 self.bbox = bbox
 
             return hv.Polygons([[[0, 0]]])
 
+        def reset_callback(resetting):
+            self.bbox = None
+            return hv.Polygons([[[0, 0]]])
+
         @pn.depends(footprint=self.w_footprint_algo.param.value, fp_on=self.w_footprint_on.param.value)
         def selection_callback_isa(bbox, region_element, selection_expr, footprint, fp_on):
             if self.bbox is not bbox:
@@ -423,8 +424,10 @@ class ClassificationApp:
         dmap_isa.opts(title='Instance Space')
 
         selection_pca = SelectionExpr(source=dmap_pca)
+        sel1_dmap = hv.DynamicMap(selection_callback_pca, streams=[selection_pca])
+
         reset = PlotReset()
-        sel1_dmap = hv.DynamicMap(selection_callback_pca, streams=[selection_pca, reset])
+        reset_dmap = hv.DynamicMap(reset_callback, streams=[reset])
 
         selection_isa = SelectionExpr(source=dmap_isa)
         sel2_dmap = hv.DynamicMap(selection_callback_isa, streams=[selection_isa])
@@ -465,9 +468,9 @@ class ClassificationApp:
             button_type='default'
         )
 
-        main = (dmap_pca * sel1_dmap + dmap_isa * sel2_dmap).cols(2).opts(
+        main = (dmap_pca * sel1_dmap * reset_dmap + dmap_isa * sel2_dmap).cols(2).opts(
             opts.Layout(shared_axes=False, shared_datasource=True, framewise=True),
-            opts.Scatter(bgcolor=transparent),
+            opts.Points(bgcolor=transparent),
             opts.Polygons(show_legend=True),
             opts.Overlay(
                 legend_opts={"click_policy": "hide", },
