@@ -117,12 +117,21 @@ dark_template = f"""
   }}
 </style>
 {{% endblock %}}
+
+{{% block postamble %}}
+<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
+<link 
+    href="https://gitlab.com/ita-ml/pyhard/-/raw/master/docs/source/imgs/blobs.svg" 
+    rel="icon" 
+    type="image/x-icon" 
+/>
+{{% endblock %}}
 """
 
 light_template = f"""
 {{% extends base %}}
 
-{{% block title %}}Instance Hardness dashboard{{% endblock %}}
+{{% block title %}}Instance Hardness app{{% endblock %}}
 
 {{% block preamble %}}
 <style>
@@ -136,6 +145,15 @@ light_template = f"""
   }}
 </style>
 {{% endblock %}}
+
+{{% block postamble %}}
+<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
+<link 
+    href="https://gitlab.com/ita-ml/pyhard/-/raw/master/docs/source/imgs/blobs.svg" 
+    rel="icon" 
+    type="image/x-icon" 
+/>
+{{% endblock %}}
 """
 
 
@@ -489,8 +507,13 @@ class BaseApp:
         self.populate_tabs()
         for _ in range(ntries):
             try:
-                pn.serve(self.get_pane, port=port, show=show, title='Instance Hardness',
-                         websocket_origin=[f'127.0.0.1:{port}', f'localhost:{port}'])
+                pn.serve(
+                    self.get_pane,
+                    port=port,
+                    show=show,
+                    title='Instance Hardness',
+                    websocket_origin=[f'127.0.0.1:{port}', f'localhost:{port}']
+                )
                 break
             except OSError:
                 print(f"Port {port} already in use. Retrying with next port...")
