@@ -17,12 +17,39 @@ from .utils import call_module_func
 
 
 def variance_filter(X: np.ndarray, threshold: float = 1e-3, indices: bool = False):
+    """
+    Filter that removes all low-variance features.
+
+    Args:
+        X (array-like): feature matrix
+        threshold (float): low variance threshold. Features with variance below that will be marked to be removed
+        indices (bool): if True, the return value will be an array of integers, rather than a boolean mask
+            (default False)
+
+    Returns:
+        array-like: If `indices` is True, returns the indices of the selected features. If False, then returns a boolean
+        mask array, whose shape is `# input_features`.
+    """
     var_thres = VarianceThreshold(threshold=threshold)
     var_thres.fit(X)
     return var_thres.get_support(indices=indices)
 
 
 def correlation_filter(X: np.ndarray, threshold=0.95, indices: bool = False) -> np.ndarray:
+    """
+    Filter that removes highly-correlated features. Groups of features are formed from correlated pairs (transitive
+    relation), and only the first element is selected.
+
+    Args:
+        X (array-like): feature matrix
+        threshold (float): correlation coefficient threshold
+        indices (bool): if True, the return value will be an array of integers, rather than a boolean mask
+            (default False)
+
+    Returns:
+        array-like: If `indices` is True, returns the indices of the selected features. If False, then returns a boolean
+        mask array, whose shape is `# input_features`.
+    """
     n_feat = X.shape[1]
     selected = set(range(n_feat))
     corr = np.corrcoef(X.T, rowvar=True)
@@ -50,15 +77,18 @@ def filtfeat(X: np.ndarray, Y: np.ndarray, method: str = 'NCA', max_n_features:
     Filter feature selection. If Y has more than one column, than applies a rank aggregation method to the multi
     selections.
 
-    :param 2D array-like X: input features array
-    :param 2D array-like Y: output performance array
-    :param str method: whether Neighborhood Component Analysis (NCA, default) or Information Theoretic based (IT)
-    :param max_n_features: max number if features to be selected. Defaults to 10
-    :param names: list with features names (default None). If provided, returns a list of selected features by name;
-        otherwise, returns a list of indices (int)
-    :param int n_jobs: Number of jobs to run in parallel. `-1` means using all processors. Defaults to 1
-    :param kwargs: optional paramters passed to the feature selection method
-    :return: array-like of selected feature
+    Args:
+        X (2D array-like): input features array
+        Y (2D array-like): output performance array
+        method (str): either Neighborhood Component Analysis (NCA, default) or Information Theoretic based (IT)
+        max_n_features (int): max number if features to be selected (default 10)
+        names (list): list with features names (default None). If provided, returns a list of selected features by name;
+            otherwise, returns a list of indices (int)
+        n_jobs (int): number of jobs to run in parallel. `-1` means using all processors. Defaults to 1
+        **kwargs: optional paramters passed to the feature selection method
+
+    Returns:
+        list: Selected features
     """
     check_array(X, ensure_2d=True)
     check_array(Y, ensure_2d=True)
